lavalink_rs.model.search API documentation

# lavalink_rs.model.search

class SearchEngines:
def youtube(query: str) -> str:

The type of the None singleton.

def youtube_music(query: str) -> str:

The type of the None singleton.

def soundcloud(query: str) -> str:

The type of the None singleton.

def spotify(query: str) -> str:

The type of the None singleton.

def spotify_recommended( query: str, parameters: SpotifyRecommendedParameters) -> str:

The type of the None singleton.

def apple_music(query: str) -> str:

The type of the None singleton.

def deezer(query: str) -> str:

The type of the None singleton.

def deezer_isrc(query: str) -> str:

The type of the None singleton.

def yandex_music(query: str) -> str:

The type of the None singleton.

def flowery_tts( query: str, parameters: FloweryTTSParameters) -> str:

The type of the None singleton.

class SpotifyRecommendedParameters:

Any of the seed fields must have a value.

Spotify documentation can be found here

market: str
max_tempo: int
max_acousticness: float
target_acousticness: float
target_mode: float
max_speechiness: float
target_speechiness: float
max_time_signature: float
min_duration_ms: int
min_mode: float
min_tempo: int
max_duration_ms: int
target_popularity: int
min_speechiness: float
min_time_signature: float
seed_artists: str
min_instrumentalness: float
min_popularity: int
max_popularity: int
min_valence: float
seed_genres: str
target_energy: float
target_liveness: float
max_valence: float
max_mode: float
limit: int
min_energy: float
max_key: float
max_instrumentalness: float
max_loudness: int
min_danceability: float
min_key: float
target_danceability: float
max_danceability: float
target_duration_ms: int
target_instrumentalness: float
min_loudness: int
target_key: float
min_liveness: float
seed_tracks: str
target_time_signature: float
target_loudness: int
target_valence: float
max_liveness: float
min_acousticness: float
max_energy: float
target_tempo: int
class FloweryTTSParameters:
voice: str

A list of voices can be found here

silence: int

The silence parameter is in milliseconds. Range is 0 to 10000. The default is 0.

audio_format: str

Supported formats are: mp3, ogg_opus, ogg_vorbis, aac, wav, and flac.

speed: float

The speed parameter is a float between 0.5 and 10. The default is 1.0. (0.5 is half speed, 2.0 is double speed, etc.)

translate: bool

TODO: Document this.